@@ -1,4 +1,4 @@
-# Copyright 2011-2017, Damian Johnson and The Tor Project
+# Copyright 2011-2019, Damian Johnson and The Tor Project
 # See LICENSE for licensing information
 
 """
@@ -104,7 +104,7 @@ class Entry(object):
     """
     Provides individual lines of connection information.
 
-    :returns: **list** of **ConnectionLine** concerning this entry
+    :returns: **list** of :class:`nyx.panel.connection.Line` concerning this entry
     """
 
     if self._lines is None:
@@ -187,15 +187,15 @@ class ConnectionEntry(Entry):
     self._connection = connection
 
   def _get_lines(self):
-    fingerprint, nickname, locale = None, None, None
+    fingerprint, nickname = None, None
 
     if self.get_type() in (Category.OUTBOUND, Category.CIRCUIT, Category.DIRECTORY, Category.EXIT):
       fingerprint = nyx.tracker.get_consensus_tracker().get_relay_fingerprints(self._connection.remote_address).get(self._connection.remote_port)
-      locale = tor_controller().get_info('ip-to-country/%s' % self._connection.remote_address, None)
 
       if fingerprint:
         nickname = nyx.tracker.get_consensus_tracker().get_relay_nickname(fingerprint)
 
+    locale = tor_controller().get_info('ip-to-country/%s' % self._connection.remote_address, None)
     return [Line(self, LineType.CONNECTION, self._connection, None, fingerprint, nickname, locale)]
 
   def _get_type(self):
@@ -232,10 +232,7 @@ class ConnectionEntry(Entry):
       return True
 
     if self.get_type() == Category.INBOUND:
-      controller = tor_controller()
-
-      if controller.is_user_traffic_allowed().inbound:
-        return len(nyx.tracker.get_consensus_tracker().get_relay_fingerprints(self._connection.remote_address)) == 0
+      return len(nyx.tracker.get_consensus_tracker().get_relay_fingerprints(self._connection.remote_address)) == 0
     elif self.get_type() == Category.EXIT:
       # DNS connections exiting us aren't private (since they're hitting our
       # resolvers). Everything else is.
@@ -252,7 +249,7 @@ class CircuitEntry(Entry):
 
   def _get_lines(self):
     def line(fingerprint, line_type):
-      address, port, nickname, locale = '0.0.0.0', 0, None, None
+      address, port, nickname = '0.0.0.0', 0, None
       consensus_tracker = nyx.tracker.get_consensus_tracker()
 
       if fingerprint is not None:
@@ -391,7 +388,7 @@ class ConnectionPanel(nyx.panel.DaemonPanel):
 
     def _show_exiting_port_usage():
       counts = {}
-      key_width = max(map(len, self._exit_port_usage.keys()))
+      key_width = max(map(len, self._exit_port_usage.keys())) if self._exit_port_usage else 0
 
       for k, v in self._exit_port_usage.items():
         usage = connection.port_usage(k)
@@ -537,13 +534,13 @@ class ConnectionPanel(nyx.panel.DaemonPanel):
       if self._halt:
         return
 
-      if entry.is_private() and line.connection not in self._counted_connections:
+      if entry.is_private() and line.connection.remote_address not in self._counted_connections:
         if entry.get_type() == Category.INBOUND and line.locale:
           self._client_locale_usage[line.locale] = self._client_locale_usage.get(line.locale, 0) + 1
         elif entry.get_type() == Category.EXIT:
           self._exit_port_usage[line.connection.remote_port] = self._exit_port_usage.get(line.connection.remote_port, 0) + 1
 
-        self._counted_connections.add(line.connection)
+        self._counted_connections.add(line.connection.remote_address)
 
     self._entries = sorted(new_entries, key = lambda entry: [entry.sort_value(attr) for attr in self._sort_order])
     self._last_resource_fetch = resolution_count
@@ -657,7 +654,7 @@ def _draw_details(subwindow, selected):
   else:
     address = '<scrubbed>' if selected.entry.is_private() else selected.connection.remote_address
     subwindow.addstr(2, 1, 'address: %s:%s' % (address, selected.connection.remote_port), *attr)
-    subwindow.addstr(2, 2, 'locale: %s' % ('??' if selected.entry.is_private() else (selected.locale if selected.locale else '??')), *attr)
+    subwindow.addstr(2, 2, 'locale: %s' % (selected.locale if selected.locale and not selected.entry.is_private() else '??'), *attr)
 
     matches = nyx.tracker.get_consensus_tracker().get_relay_fingerprints(selected.connection.remote_address)
 
